/* This kind implements local parsing of the fortunes.txt file */
enyo.kind({
	name: "FortuneJar",
	kind: "enyo.Component",
	_lastPick: -1,
	_fortunes: [],
	_deferredCallbacks: [],
	components: [
		{ kind: enyo.WebService, name: "loader", url: "assets/fortunes.txt",
				handleAs: "text", onResponse: "parseFortunes"}
	],

	create: function () {
		this.inherited(arguments);
		this.$.loader.send({});
	},

	parseFortunes: function(inSender, inResponse) {
		if (!inResponse.data) {
			return;
		}
		
		this._fortunes = inResponse.data.split("\n%\n");
		this._fortunes = enyo.map(this._fortunes, this.formatFortune, this);
		
		// handle any callbacks queued while we were waiting
		enyo.forEach(this._deferredCallbacks, function(callback) {
				this.fetchNewFortune(callback);	}, this);
		this._deferredCallbacks = [];
	},

	formatFortune: function(fortune) {
		// turn -- into mdash characters and 
		// turn LF/TAB into HTML break plus nonbreaking spaces
		return fortune.replace(/\-\- /g, "&mdash; ")
				.replace(/\n\t/g, "<br>&nbsp;&nbsp;&nbsp;&nbsp; ");
	},
	
	fetchNewFortune: function(callback) {
		if (this._fortunes.length === 0) {
			this._deferredCallbacks.push(callback);
			return;
		}
		
		var pick;
		do {
			pick = Math.floor(Math.random() * 
				this._fortunes.length);
		} while (pick === this._lastPick);
		this._lastPick = pick;
		callback(this._fortunes[pick]);
	}
}); 
