#!/bin/bash

# the folder this script is in (*/bootplate/tools)
TOOLS=$(cd `dirname "$0"`; pwd)

# application root
SRC=`dirname "$TOOLS"`

# enyo location
ENYO="$SRC/enyo"

# deploy script location
DEPLOY="$ENYO/tools/deploy.js"

# check for node, but quietly
if command -v node >/dev/null 2>&1; then
	# use node to invoke deploy with imported parameters
	echo "node $DEPLOY -T -s $SRC -o $SRC/deploy $@"
	node "$DEPLOY" -T -s "$SRC" -o "$SRC/deploy" $@
else
	echo "No node found in path"
	exit 1
fi

# copy files and package if deploying to cordova webos
while [ "$1" != "" ]; do
	case $1 in
		-w | --cordova-webos )
			echo " "
    			echo "Packaging webOS application..."
    			
			# copy appinfo.json file
			cp "$SRC/appinfo.json" "$SRC/deploy" > /dev/null
			
			# collect the list of services in %SRC%\services
			PKG_SERVICES=""
			IFS=$'\n'
			for d in $(find "$SRC/services" -mindepth 1 -maxdepth 1 -type d) ; do
				PKG_SERVICES="$PKG_SERVICES\"$d\" "
			done
			
			# package it up
			mkdir -p "$SRC/bin"
			eval "ares-package.sh -o \"$SRC/bin\" \"$SRC/deploy\" $PKG_SERVICES \"$SRC/package\""
			;;
	esac
	shift
done
